<?php
/**
 * @file
 * Contains Attribute for miniOrange OAuth Client Module.
 */

/**
 * Showing Settings form.
 */
namespace Drupal\miniorange_oauth_client\Form;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Render;
use Drupal\miniorange_oauth_client\Utilities;
use Drupal\miniorange_oauth_client\MiniorangeOAuthClientConstants;

class MiniorangeRFD extends FormBase {

  public function getFormId() {
    return 'miniorange_oauth_client_rfd';
  }


  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['markup_library'] = array(
      '#attached' => array(
        'library' => array(
          "miniorange_oauth_client/miniorange_oauth_client.admin",
          "miniorange_oauth_client/miniorange_oauth_client.style_settings",
          "miniorange_oauth_client/miniorange_oauth_client.module",
        )
      ),
    );

    $user_email = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_client_customer_admin_email');
    $phone = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_client_customer_admin_phone');

    $form['markup_1'] = array(
      '#markup' =>'<div class="mo_oauth_table_layout_1"><div class="mo_oauth_table_layout mo_oauth_container">'
    );

    $form['mo_oauth_vertical_tabs'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-publication',
    );

    /**
     * Support form
     */
    $form['miniorange_support'] = array (
      '#type' => 'details',
      '#title' => t('Support'),
      '#group' => 'mo_oauth_vertical_tabs',
    );

    $form['miniorange_support']['markup_1'] = array(
      '#markup' => t('<h3>Support</h3><hr><p class="mo_oauth_highlight_background_note">Need any help? We can help you with configuring miniOrange OAuth Client module on your site. Just send us a query and we will get back to you soon.</p>'),
    );
    $form['miniorange_support']['mo_oauth_support_email_address'] = array(
      '#type' => 'email',
      '#title' => t('Email <span style="color: red">*</span>'),
      '#default_value' => $user_email,
      '#attributes' => array('placeholder' => t('Enter your email'), 'style' => 'width:99%;margin-bottom:1%;'),
    );
    $form['miniorange_support']['mo_oauth_support_phone_number'] = array(
      '#type' => 'textfield',
      '#title' => t('Phone'),
      '#default_value' => $phone,
      '#attributes' => array('placeholder' => t('Enter number with country code Eg. +00xxxxxxxxxx'), 'style' => 'width:99%;margin-bottom:1%;'),
    );
    $form['miniorange_support']['mo_oauth_support_query'] = array(
      '#type' => 'textarea',
      '#title' => t('Query <span style="color: red">*</span>'),
      '#attributes' => array('placeholder' => t('Describe your query here!'), 'style' => 'width:99%'),
      '#suffix' => '<br>',
    );
    $form['miniorange_support']['actions']['submit'] = array(
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => t('Submit query'),
    );
    $form['miniorange_support']['markup_support_note'] = array(
      '#markup' => t('<div><br/><br/>If you want custom features in the module, just drop an email to <a href="mailto:info@xecurify.com">info@xecurify.com</a> or <a href="mailto:'.MiniorangeOAuthClientConstants::SUPPORT_EMAIL.'">'.MiniorangeOAuthClientConstants::SUPPORT_EMAIL.'</a></div><br><hr><br>'),
    );


    /**
     * Request for trial form
     */
    $form['miniorange_trial_request'] = array (
      '#type' => 'details',
      '#title' => t('Request For Trial'),
      '#group' => 'mo_oauth_vertical_tabs',
    );
    $form['miniorange_trial_request']['markup_2'] = array(
      '#markup' => '<h3>REQUEST FOR TRIAL</h3><hr><br><div class="mo_oauth_highlight_background_note_export"><p><strong>Want to test any of the paid modules before purchasing? </strong></p>
                          <p>Just send us a request, We will setup a demo site for you on our cloud with any of the paid modules and provide you with the administrator credentials.
                          You can configure it with your OAuth/OpenID Connect Server and test all the features as per your requirement.</p>
                          </div><br>',
    );
    $form['miniorange_trial_request']['mo_oauth_trial_email_address'] = array(
      '#type' => 'email',
      '#title' => t('Email <span style="color: red">*</span>'),
      '#default_value' => $user_email,
      '#attributes' => array('placeholder' => t('Enter your email'), 'style' => 'width:99%;margin-bottom:1%;'),
    );
    $form['miniorange_trial_request']['mo_oauth_trial_plan'] = array(
      '#type' => 'select',
      '#title' => t('Trial Plan'),
      '#attributes' => array('style' => 'width:99%;height:30px;margin-bottom:1%;'),
      '#options' => [
        'Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Standard Module' => t('Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Standard Module'),
        'Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Premium Module' => t('Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Premium Module'),
        'Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Enterprise Module' => t('Drupal ' . Utilities::mo_get_drupal_core_version() . ' OAuth Enterprise Module'),
        'Not Sure' => t('Not Sure'),
      ],
    );

    $form['miniorange_trial_request']['mo_oauth_trial_description'] = array(
      '#type' => 'textarea',
      '#title' => t('Description <span style="color: red">*</span>'),
      '#attributes' => array('placeholder' => t('Describe your use case here!'), 'style' => 'width:99%;'),
      '#suffix' => '<br>',
    );
    $form['miniorange_trial_request']['actions']['submit'] = array(
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => t('Send Trial Request'),
    );
    $form['miniorange_trial_request']['markup_trial_note'] = array(
      '#markup' => t('<div><br/><br/>If you are not sure with which plan you should go with, get in touch with us on <a href="mailto:'.MiniorangeOAuthClientConstants::SUPPORT_EMAIL.'">'.MiniorangeOAuthClientConstants::SUPPORT_EMAIL.'</a> and we will assist you with the suitable plan.</div><br><hr><br>'),
    );

    $form['miniorange_support_tab_end'] = array(
      '#markup' => t('</div>'),
    );

    Utilities::nofeaturelisted($form, $form_state);

    return $form;
  }

  public function validateForm(array &$form, FormStateInterface $form_state) {
    $form_values = $form_state->getValues();

    if( $form_values['mo_oauth_vertical_tabs__active_tab'] === 'edit-miniorange-support' ) {
      if( !\Drupal::service('email.validator')->isValid( $form_values['mo_oauth_support_email_address'] ) ) {
        $form_state->setErrorByName('mo_oauth_support_email_address', $this->t('The email address is not valid.'));
      }
      if( empty( $form_values['mo_oauth_support_query'] ) ) {
        $form_state->setErrorByName('mo_oauth_support_query', $this->t('The <b><u>Query</u></b> fields is mandatory.'));
      }
    } elseif( $form_values['mo_oauth_vertical_tabs__active_tab'] === 'edit-miniorange-trial-request' ) {
      if( !\Drupal::service('email.validator')->isValid( $form_values['mo_oauth_trial_email_address'] ) ) {
        $form_state->setErrorByName('mo_oauth_trial_email_address', $this->t('The email address is not valid.'));
      }
      if( empty( $form_values['mo_oauth_trial_description'] ) ) {
        $form_state->setErrorByName('mo_oauth_trial_description', $this->t('The <b><u>Description</u></b> fields is mandatory.'));
      }
    }
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_values = $form_state->getValues();
    $email = ''; $phone = ''; $query = ''; $query_type = '';

    if( $form_values['mo_oauth_vertical_tabs__active_tab'] === 'edit-miniorange-support' ) {
      $email = $form_values['mo_oauth_support_email_address'];
      $phone = $form_values['mo_oauth_support_phone_number'];
      $query = $form_values['mo_oauth_support_query'];
      $query_type = 'Support';

    }elseif ( $form_values['mo_oauth_vertical_tabs__active_tab'] === 'edit-miniorange-trial-request' ) {
      $email = $form_values['mo_oauth_trial_email_address'];
      $query = $form_values['mo_oauth_trial_plan'] .' : '.$form_values['mo_oauth_trial_description'];
      $query_type = 'Trial Request';

    }
    Utilities::send_support_query( $email, $phone, $query, $query_type );
  }

  public static function setup_call(array &$form, FormStateInterface $form_state){
    Utilities::schedule_a_call($form, $form_state);
  }
}
